@@ -32,21 +32,24 @@ def run(inputfile: Path, outputdir: Path, config: Path, ncrna_lst: list) -> None
     config = Config(config)
     logger = Logger(f"{outputdir}/evatool.log")
     # logger.info("Start pre-processing")
-    print(f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}: Start pre-processing")
+    print(f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}: Start pre-processing...")
     fastq_result = Fastq(inputfile, outputdir, config=config, log=logger, ncrna_lst=ncrna_lst)
     fastq_result.process_fastq()
     tag_result = Tag(fastq=fastq_result)
     tag_result.pocess_stat()
+    print(f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}: Successed in pre-processing!")
     # logger.info("Start mapping...")
-    print(f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}: Start mapping")
+    print(f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}: Start mapping...")
     sam_result = SAM(fastq=fastq_result)
     sam_result.get_sam()
     bam_result = Bam(fastq=fastq_result, tag=tag_result)
     bam_result.process_bam()
     # logger.info("Start quantification")
-    print(f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}: Start quantification")
+    print(f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}: Successed in mapping!")
+    print(f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}: Start quantification...")
     stat_result = Stat(fastq=fastq_result, tag=tag_result)
     stat_result.stat_match()
+    print(f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}: Successed quantification!")
     return 1
 
 
@@ -82,7 +85,7 @@ def main():
         report_result = Report(configure.input, configure.output, configure.config, configure.ncrna)
         report_result.prepare_html()
         logger.info(f"Finished! The result are stored in {configure.output}!")
-        print(f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}: Success!")
+        print(f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}: Success! All results are stored in {configure.output}!")
     else:
         print(f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}: Failed!")
         logger.error(f"Failed in processing your data, please check the problems in the log file: {configure.output}/evatool.log")
